@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -10,8 +10,8 @@ import time
 
 PYVERSION = sys.version.split()[0]
 
-if PYVERSION >= "3" or PYVERSION < "2.6":
-    exit("[%s] [CRITICAL] incompatible Python version detected ('%s'). To successfully run sqlmap you'll have to use version 2.6.x or 2.7.x (visit 'https://www.python.org/downloads/')" % (time.strftime("%X"), PYVERSION))
+if PYVERSION < "2.6":
+    sys.exit("[%s] [CRITICAL] incompatible Python version detected ('%s'). To successfully run sqlmap you'll have to use version 2.6, 2.7 or 3.x (visit 'https://www.python.org/downloads/')" % (time.strftime("%X"), PYVERSION))
 
 errors = []
 extensions = ("bz2", "gzip", "pyexpat", "ssl", "sqlite3", "zlib")
@@ -22,7 +22,7 @@ for _ in extensions:
         errors.append(_)
 
 if errors:
-    errMsg = "missing one or more core extensions (%s) " % (", ".join("'%s'" % _ for _ in errors))
+    errMsg = "[%s] [CRITICAL] missing one or more core extensions (%s) " % (time.strftime("%X"), ", ".join("'%s'" % _ for _ in errors))
     errMsg += "most likely because current version of Python has been "
     errMsg += "built without appropriate dev packages"
-    exit(errMsg)
+    sys.exit(errMsg)
