@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -45,10 +45,10 @@ class Fingerprint(GenericFingerprint):
         # Reference: https://dev.mysql.com/doc/relnotes/mysql/<major>.<minor>/en/
 
         versions = (
-            (80000, 80021),  # MySQL 8.0
+            (80000, 80029),  # MySQL 8.0
             (60000, 60014),  # MySQL 6.0
-            (50700, 50731),  # MySQL 5.7
-            (50600, 50649),  # MySQL 5.6
+            (50700, 50737),  # MySQL 5.7
+            (50600, 50652),  # MySQL 5.6
             (50500, 50563),  # MySQL 5.5
             (50400, 50404),  # MySQL 5.4
             (50100, 50174),  # MySQL 5.1
@@ -92,8 +92,12 @@ class Fingerprint(GenericFingerprint):
                 fork = FORK.MARIADB
             elif inject.checkBooleanExpression("VERSION() LIKE '%TiDB%'"):
                 fork = FORK.TIDB
+            elif inject.checkBooleanExpression("@@VERSION_COMMENT LIKE '%drizzle%'"):
+                fork = FORK.DRIZZLE
             elif inject.checkBooleanExpression("@@VERSION_COMMENT LIKE '%Percona%'"):
                 fork = FORK.PERCONA
+            elif inject.checkBooleanExpression("AURORA_VERSION() LIKE '%'"):            # Reference: https://aws.amazon.com/premiumsupport/knowledge-center/aurora-version-number/
+                fork = FORK.AURORA
             else:
                 fork = ""
 
@@ -162,9 +166,8 @@ class Fingerprint(GenericFingerprint):
         if not conf.extensiveFp and Backend.isDbmsWithin(MYSQL_ALIASES):
             setDbms("%s %s" % (DBMS.MYSQL, Backend.getVersion()))
 
-            if Backend.isVersionGreaterOrEqualThan("5"):
+            if Backend.isVersionGreaterOrEqualThan("5") or inject.checkBooleanExpression("DATABASE() LIKE SCHEMA()"):
                 kb.data.has_information_schema = True
-
             self.getBanner()
 
             return True
@@ -196,16 +199,16 @@ class Fingerprint(GenericFingerprint):
             # reading information_schema on some platforms is causing annoying timeout exits
             # Reference: http://bugs.mysql.com/bug.php?id=15855
 
+            kb.data.has_information_schema = True
+
             # Determine if it is MySQL >= 8.0.0
             if inject.checkBooleanExpression("ISNULL(JSON_STORAGE_FREE(NULL))"):
-                kb.data.has_information_schema = True
                 Backend.setVersion(">= 8.0.0")
                 setDbms("%s 8" % DBMS.MYSQL)
                 self.getBanner()
 
             # Determine if it is MySQL >= 5.0.0
             elif inject.checkBooleanExpression("ISNULL(TIMESTAMPADD(MINUTE,[RANDNUM],NULL))"):
-                kb.data.has_information_schema = True
                 Backend.setVersion(">= 5.0.0")
                 setDbms("%s 5" % DBMS.MYSQL)
                 self.getBanner()
@@ -265,6 +268,8 @@ class Fingerprint(GenericFingerprint):
                 setDbms("%s 4" % DBMS.MYSQL)
                 self.getBanner()
 
+                kb.data.has_information_schema = False
+
                 if not conf.extensiveFp:
                     return True
 
@@ -287,6 +292,8 @@ class Fingerprint(GenericFingerprint):
                 setDbms("%s 3" % DBMS.MYSQL)
                 self.getBanner()
 
+                kb.data.has_information_schema = False
+
             return True
         else:
             warnMsg = "the back-end DBMS is not %s" % DBMS.MYSQL
